from typing import Text
from sqlalchemy.orm import Session
import pytest
from rasax.community import metrics
from rasax.community import config
from rasax.community.services.data_service import DataService
from rasax.community.services.domain_service import DomainService
from rasax.community.services.story_service import StoryService
from rasax.community.version import __version__


def test_get_start_event(
    session: Session,
    domain_service: DomainService,
    data_service: DataService,
    story_service: StoryService,
):
    domain = domain_service.get_or_create_domain()
    nlu_data = data_service.get_nlu_training_data_object()
    stories = story_service.fetch_stories()

    actual = metrics._get_rasa_x_start_event(session, "test", domain, nlu_data, stories)

    assert actual == {
        "project": "test",
        "rasa_x": __version__,
        "num_intent_examples": 0,
        "num_entity_examples": 0,
        "num_actions": 0,
        "num_templates": 0,
        "num_slots": 0,
        "num_forms": 0,
        "num_intents": 0,
        "num_entities": 0,
        "num_stories": 0,
        "num_conversations": 0,
        "num_models": 0,
        "num_lookuptable_files": 0,
        "num_lookuptable_entries": 0,
        "num_synonyms": 0,
        "num_regexes": 0,
    }


@pytest.mark.parametrize(
    "uuid, enabled", [("1234", True), ("5432", False), ("12344", True)]
)
def test_set_metrics_config_from_env_with_uuid(uuid: Text, enabled: bool):
    config.metrics_consent_given = enabled
    config.metrics_user_id = uuid
    metrics.set_metrics_config_from_env()

    assert metrics.are_metrics_enabled() == enabled
    assert metrics.metrics_id() == uuid


def test_set_metrics_config_from_env_without_uuid():
    config.metrics_user_id = None
    metrics.set_metrics_config_from_env()

    assert len(metrics.metrics_id()) >= 32
